==> PSyclone-2.4.0-py3-none-any.whl: psyclone/tests/test_files/dynamo0p3/22.2_intergrid_3levels.f90 <==
! -----------------------------------------------------------------------------
! BSD 3-Clause License
!
! Copyright (c) 2017-2020, Science and Technology Facilities Council
! All rights reserved.
!
! Redistribution and use in source and binary forms, with or without
! modification, are permitted provided that the following conditions are met:
!
! * Redistributions of source code must retain the above copyright notice, this
!   list of conditions and the following disclaimer.
!
! * Redistributions in binary form must reproduce the above copyright notice,
!   this list of conditions and the following disclaimer in the documentation
!   and/or other materials provided with the distribution.
!
! * Neither the name of the copyright holder nor the names of its
!   contributors may be used to endorse or promote products derived from
!   this software without specific prior written permission.
!
! THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
! "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
! LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
! FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
! COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
! INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
! BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
! LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
! CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
! LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
! ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
! POSSIBILITY OF SUCH DAMAGE.
! -----------------------------------------------------------------------------
! Authors R. W. Ford and A. R. Porter, STFC Daresbury Lab
! Modified I. Kavcic, Met Office

program restrict_prolong

  ! Description: invoke containing restrictions/prolongations where
  ! fields swap roles (what was 'fine' becomes 'coarse')
  use field_mod,                only: field_type
  use restrict_test_kernel_mod, only: restrict_test_kernel_type
  use prolong_test_kernel_mod,  only: prolong_test_kernel_type

  implicit none

  type(field_type) :: fld_f, fld_m, fld_c

  call invoke(                                         &
              prolong_test_kernel_type(fld_m, fld_c),  & ! coarse -> medium
              prolong_test_kernel_type(fld_f, fld_m),  & ! medium -> fine
              restrict_test_kernel_type(fld_m, fld_f), & ! fine -> medium
              restrict_test_kernel_type(fld_c, fld_m) )  ! medium -> coarse

end program restrict_prolong

==> PSyclone-3.0.0-py3-none-any.whl: psyclone/tests/test_files/dynamo0p3/22.2_intergrid_3levels.f90 <==
! -----------------------------------------------------------------------------
! BSD 3-Clause License
!
! Copyright (c) 2017-2024, Science and Technology Facilities Council
! All rights reserved.
!
! Redistribution and use in source and binary forms, with or without
! modification, are permitted provided that the following conditions are met:
!
! * Redistributions of source code must retain the above copyright notice, this
!   list of conditions and the following disclaimer.
!
! * Redistributions in binary form must reproduce the above copyright notice,
!   this list of conditions and the following disclaimer in the documentation
!   and/or other materials provided with the distribution.
!
! * Neither the name of the copyright holder nor the names of its
!   contributors may be used to endorse or promote products derived from
!   this software without specific prior written permission.
!
! THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
! "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
! LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
! FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
! COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
! INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
! BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
! LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
! CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
! LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
! ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
! POSSIBILITY OF SUCH DAMAGE.
! -----------------------------------------------------------------------------
! Authors R. W. Ford and A. R. Porter, STFC Daresbury Lab
! Modified I. Kavcic, Met Office

program restrict_prolong

  ! Description: invoke containing restrictions/prolongations where
  ! fields swap roles (what was 'fine' becomes 'coarse'). Once of the fields is
  ! also named so as to provoke a name clash with the standard name that
  ! PSyclone would generate for a colour map.
  use field_mod,                only: field_type
  use restrict_test_kernel_mod, only: restrict_test_kernel_type
  use prolong_test_kernel_mod,  only: prolong_test_kernel_type

  implicit none

  type(field_type) :: fld_f, fld_m, cmap_fld_c

  call invoke(                                             &
              prolong_test_kernel_type(fld_m, cmap_fld_c), & ! coarse -> medium
              prolong_test_kernel_type(fld_f, fld_m),      & ! medium -> fine
              restrict_test_kernel_type(fld_m, fld_f),     & ! fine -> medium
              restrict_test_kernel_type(cmap_fld_c, fld_m) ) ! medium -> coarse

end program restrict_prolong
